@@ -9,37 +9,32 @@ Interface::
       # iterate over pages:
       for page in dvi:
           w, h, d = page.width, page.height, page.descent
-          for x,y,font,glyph,width in page.text:
+          for x, y, font, glyph, width in page.text:
               fontname = font.texname
               pointsize = font.size
               ...
-          for x,y,height,width in page.boxes:
+          for x, y, height, width in page.boxes:
               ...
-
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import six
-from six.moves import xrange
 
 from collections import namedtuple
-import errno
-from functools import partial, wraps
-import matplotlib
-import matplotlib.cbook as mpl_cbook
-from matplotlib.compat import subprocess
-from matplotlib import rcParams
-import numpy as np
+import enum
+from functools import lru_cache, partial, wraps
+import logging
+import os
 import re
 import struct
-import sys
 import textwrap
-import os
 
-if six.PY3:
-    def ord(x):
-        return x
+import numpy as np
+
+from matplotlib import cbook, rcParams
+
+_log = logging.getLogger(__name__)
+
+# Many dvi related files are looked for by external processes, require
+# additional parsing, and are used many times per rendering, which is why they
+# are cached using lru_cache().
 
 # Dvi is a bytecode format documented in
 # http://mirrors.ctan.org/systems/knuth/dist/texware/dvitype.web
@@ -57,7 +52,7 @@ if six.PY3:
 #              just stops reading)
 #   finale:    the finale (unimplemented in our current implementation)
 
-_dvistate = mpl_cbook.Bunch(pre=0, outer=1, inpage=2, post_post=3, finale=4)
+_dvistate = enum.Enum('DviState', 'pre outer inpage post_post finale')
 
 # The marks on a page consist of text and boxes. A page also has dimensions.
 Page = namedtuple('Page', 'text boxes height width descent')
@@ -167,14 +162,14 @@ def _dispatch(table, min, max=None, state=None, args=('raw',)):
         if max is None:
             table[min] = wrapper
         else:
-            for i in xrange(min, max+1):
+            for i in range(min, max+1):
                 assert table[i] is None
                 table[i] = wrapper
         return wrapper
     return decorate
 
 
-class Dvi(object):
+class Dvi:
     """
     A reader for a dvi ("device-independent") file, as produced by TeX.
     The current implementation can only iterate through pages in order,
@@ -184,13 +179,13 @@ class Dvi(object):
     file upon exit. Pages can be read via iteration. Here is an overly
     simple way to extract text without trying to detect whitespace::
 
-    >>> with matplotlib.dviread.Dvi('input.dvi', 72) as dvi:
-    >>>     for page in dvi:
-    >>>         print ''.join(unichr(t.glyph) for t in page.text)
+        >>> with matplotlib.dviread.Dvi('input.dvi', 72) as dvi:
+        ...     for page in dvi:
+        ...         print(''.join(chr(t.glyph) for t in page.text))
     """
     # dispatch table
-    _dtable = [None for _ in xrange(256)]
-    dispatch = partial(_dispatch, _dtable)
+    _dtable = [None] * 256
+    _dispatch = partial(_dispatch, _dtable)
 
     def __init__(self, filename, dpi):
         """
@@ -199,7 +194,7 @@ class Dvi(object):
         *dpi* only sets the units and does not limit the resolution.
         Use None to return TeX's internal units.
         """
-        matplotlib.verbose.report('Dvi: ' + filename, 'debug')
+        _log.debug('Dvi: %s', filename)
         self.file = open(filename, 'rb')
         self.dpi = dpi
         self.fonts = {}
@@ -245,12 +240,8 @@ class Dvi(object):
             precision is not lost and coordinate values are not clipped to
             integers.
         """
-        while True:
-            have_page = self._read()
-            if have_page:
-                yield self._output()
-            else:
-                break
+        while self._read():
+            yield self._output()
 
     def close(self):
         """
@@ -306,11 +297,11 @@ class Dvi(object):
         False if there were no more pages.
         """
         while True:
-            byte = ord(self.file.read(1)[0])
+            byte = self.file.read(1)[0]
             self._dtable[byte](self, byte)
             if byte == 140:                         # end of page
                 return True
-            if self.state == _dvistate.post_post:   # end of file
+            if self.state is _dvistate.post_post:   # end of file
                 self.close()
                 return False
 
@@ -320,29 +311,29 @@ class Dvi(object):
         Signedness is determined by the *signed* keyword.
         """
         str = self.file.read(nbytes)
-        value = ord(str[0])
+        value = str[0]
         if signed and value >= 0x80:
             value = value - 0x100
         for i in range(1, nbytes):
-            value = 0x100*value + ord(str[i])
+            value = 0x100*value + str[i]
         return value
 
-    @dispatch(min=0, max=127, state=_dvistate.inpage)
+    @_dispatch(min=0, max=127, state=_dvistate.inpage)
     def _set_char_immediate(self, char):
         self._put_char_real(char)
         self.h += self.fonts[self.f]._width_of(char)
 
-    @dispatch(min=128, max=131, state=_dvistate.inpage, args=('olen1',))
+    @_dispatch(min=128, max=131, state=_dvistate.inpage, args=('olen1',))
     def _set_char(self, char):
         self._put_char_real(char)
         self.h += self.fonts[self.f]._width_of(char)
 
-    @dispatch(132, state=_dvistate.inpage, args=('s4', 's4'))
+    @_dispatch(132, state=_dvistate.inpage, args=('s4', 's4'))
     def _set_rule(self, a, b):
         self._put_rule_real(a, b)
         self.h += b
 
-    @dispatch(min=133, max=136, state=_dvistate.inpage, args=('olen1',))
+    @_dispatch(min=133, max=136, state=_dvistate.inpage, args=('olen1',))
     def _put_char(self, char):
         self._put_char_real(char)
 
@@ -364,7 +355,7 @@ class Dvi(object):
                                    _mul2012(a, scale), _mul2012(b, scale))
                                for x, y, a, b in font._vf[char].boxes])
 
-    @dispatch(137, state=_dvistate.inpage, args=('s4', 's4'))
+    @_dispatch(137, state=_dvistate.inpage, args=('s4', 's4'))
     def _put_rule(self, a, b):
         self._put_rule_real(a, b)
 
@@ -372,11 +363,11 @@ class Dvi(object):
         if a > 0 and b > 0:
             self.boxes.append(Box(self.h, self.v, a, b))
 
-    @dispatch(138)
+    @_dispatch(138)
     def _nop(self, _):
         pass
 
-    @dispatch(139, state=_dvistate.outer, args=('s4',)*11)
+    @_dispatch(139, state=_dvistate.outer, args=('s4',)*11)
     def _bop(self, c0, c1, c2, c3, c4, c5, c6, c7, c8, c9, p):
         self.state = _dvistate.inpage
         self.h, self.v, self.w, self.x, self.y, self.z = 0, 0, 0, 0, 0, 0
@@ -384,75 +375,68 @@ class Dvi(object):
         self.text = []          # list of Text objects
         self.boxes = []         # list of Box objects
 
-    @dispatch(140, state=_dvistate.inpage)
+    @_dispatch(140, state=_dvistate.inpage)
     def _eop(self, _):
         self.state = _dvistate.outer
         del self.h, self.v, self.w, self.x, self.y, self.z, self.stack
 
-    @dispatch(141, state=_dvistate.inpage)
+    @_dispatch(141, state=_dvistate.inpage)
     def _push(self, _):
         self.stack.append((self.h, self.v, self.w, self.x, self.y, self.z))
 
-    @dispatch(142, state=_dvistate.inpage)
+    @_dispatch(142, state=_dvistate.inpage)
     def _pop(self, _):
         self.h, self.v, self.w, self.x, self.y, self.z = self.stack.pop()
 
-    @dispatch(min=143, max=146, state=_dvistate.inpage, args=('slen1',))
+    @_dispatch(min=143, max=146, state=_dvistate.inpage, args=('slen1',))
     def _right(self, b):
         self.h += b
 
-    @dispatch(min=147, max=151, state=_dvistate.inpage, args=('slen',))
+    @_dispatch(min=147, max=151, state=_dvistate.inpage, args=('slen',))
     def _right_w(self, new_w):
         if new_w is not None:
             self.w = new_w
         self.h += self.w
 
-    @dispatch(min=152, max=156, state=_dvistate.inpage, args=('slen',))
+    @_dispatch(min=152, max=156, state=_dvistate.inpage, args=('slen',))
     def _right_x(self, new_x):
         if new_x is not None:
             self.x = new_x
         self.h += self.x
 
-    @dispatch(min=157, max=160, state=_dvistate.inpage, args=('slen1',))
+    @_dispatch(min=157, max=160, state=_dvistate.inpage, args=('slen1',))
     def _down(self, a):
         self.v += a
 
-    @dispatch(min=161, max=165, state=_dvistate.inpage, args=('slen',))
+    @_dispatch(min=161, max=165, state=_dvistate.inpage, args=('slen',))
     def _down_y(self, new_y):
         if new_y is not None:
             self.y = new_y
         self.v += self.y
 
-    @dispatch(min=166, max=170, state=_dvistate.inpage, args=('slen',))
+    @_dispatch(min=166, max=170, state=_dvistate.inpage, args=('slen',))
     def _down_z(self, new_z):
         if new_z is not None:
             self.z = new_z
         self.v += self.z
 
-    @dispatch(min=171, max=234, state=_dvistate.inpage)
+    @_dispatch(min=171, max=234, state=_dvistate.inpage)
     def _fnt_num_immediate(self, k):
         self.f = k
 
-    @dispatch(min=235, max=238, state=_dvistate.inpage, args=('olen1',))
+    @_dispatch(min=235, max=238, state=_dvistate.inpage, args=('olen1',))
     def _fnt_num(self, new_f):
         self.f = new_f
 
-    @dispatch(min=239, max=242, args=('ulen1',))
+    @_dispatch(min=239, max=242, args=('ulen1',))
     def _xxx(self, datalen):
         special = self.file.read(datalen)
-        if six.PY3:
-            chr_ = chr
-        else:
-            def chr_(x):
-                return x
-        matplotlib.verbose.report(
-            'Dvi._xxx: encountered special: %s'
-            % ''.join([(32 <= ord(ch) < 127) and chr_(ch)
-                       or '<%02x>' % ord(ch)
-                       for ch in special]),
-            'debug')
+        _log.debug(
+            'Dvi._xxx: encountered special: %s',
+            ''.join([chr(ch) if 32 <= ch < 127 else '<%02x>' % ch
+                     for ch in special]))
 
-    @dispatch(min=243, max=246, args=('olen1', 'u4', 'u4', 'u4', 'u1', 'u1'))
+    @_dispatch(min=243, max=246, args=('olen1', 'u4', 'u4', 'u4', 'u1', 'u1'))
     def _fnt_def(self, k, c, s, d, a, l):
         self._fnt_def_real(k, c, s, d, a, l)
 
@@ -461,11 +445,7 @@ class Dvi(object):
         fontname = n[-l:].decode('ascii')
         tfm = _tfmfile(fontname)
         if tfm is None:
-            if six.PY2:
-                error_class = OSError
-            else:
-                error_class = FileNotFoundError
-            raise error_class("missing font metrics file: %s" % fontname)
+            raise FileNotFoundError("missing font metrics file: %s" % fontname)
         if c != 0 and tfm.checksum != 0 and c != tfm.checksum:
             raise ValueError('tfm checksum mismatch: %s' % n)
 
@@ -473,9 +453,9 @@ class Dvi(object):
 
         self.fonts[k] = DviFont(scale=s, tfm=tfm, texname=n, vf=vf)
 
-    @dispatch(247, state=_dvistate.pre, args=('u1', 'u4', 'u4', 'u4', 'u1'))
+    @_dispatch(247, state=_dvistate.pre, args=('u1', 'u4', 'u4', 'u4', 'u1'))
     def _pre(self, i, num, den, mag, k):
-        comment = self.file.read(k)
+        self.file.read(k)  # comment in the dvi file
         if i != 2:
             raise ValueError("Unknown dvi format %d" % i)
         if num != 25400000 or den != 7227 * 2**16:
@@ -491,22 +471,22 @@ class Dvi(object):
             # I think we can assume this is constant
         self.state = _dvistate.outer
 
-    @dispatch(248, state=_dvistate.outer)
+    @_dispatch(248, state=_dvistate.outer)
     def _post(self, _):
         self.state = _dvistate.post_post
         # TODO: actually read the postamble and finale?
         # currently post_post just triggers closing the file
 
-    @dispatch(249)
+    @_dispatch(249)
     def _post_post(self, _):
         raise NotImplementedError
 
-    @dispatch(min=250, max=255)
+    @_dispatch(min=250, max=255)
     def _malformed(self, offset):
         raise ValueError("unknown command: byte %d", 250 + offset)
 
 
-class DviFont(object):
+class DviFont:
     """
     Encapsulation of a font that a DVI file can refer to.
 
@@ -519,7 +499,6 @@ class DviFont(object):
 
     Parameters
     ----------
-
     scale : float
         Factor by which the font is scaled from its natural size.
     tfm : Tfm
@@ -534,7 +513,6 @@ class DviFont(object):
 
     Attributes
     ----------
-
     texname : bytes
     size : float
        Size of the font in Adobe points, converted from the slightly
@@ -547,54 +525,46 @@ class DviFont(object):
     __slots__ = ('texname', 'size', 'widths', '_scale', '_vf', '_tfm')
 
     def __init__(self, scale, tfm, texname, vf):
-        if not isinstance(texname, bytes):
-            raise ValueError("texname must be a bytestring, got %s"
-                             % type(texname))
-        self._scale, self._tfm, self.texname, self._vf = \
-            scale, tfm, texname, vf
+        cbook._check_isinstance(bytes, texname=texname)
+        self._scale = scale
+        self._tfm = tfm
+        self.texname = texname
+        self._vf = vf
         self.size = scale * (72.0 / (72.27 * 2**16))
         try:
             nchars = max(tfm.width) + 1
         except ValueError:
             nchars = 0
         self.widths = [(1000*tfm.width.get(char, 0)) >> 20
-                       for char in xrange(nchars)]
+                       for char in range(nchars)]
 
     def __eq__(self, other):
-        return self.__class__ == other.__class__ and \
-            self.texname == other.texname and self.size == other.size
+        return (type(self) == type(other)
+                and self.texname == other.texname and self.size == other.size)
 
     def __ne__(self, other):
         return not self.__eq__(other)
 
-    def _width_of(self, char):
-        """
-        Width of char in dvi units. For internal use by dviread.py.
-        """
+    def __repr__(self):
+        return "<{}: {}>".format(type(self).__name__, self.texname)
 
+    def _width_of(self, char):
+        """Width of char in dvi units."""
         width = self._tfm.width.get(char, None)
         if width is not None:
             return _mul2012(width, self._scale)
-
-        matplotlib.verbose.report(
-            'No width for char %d in font %s' % (char, self.texname),
-            'debug')
+        _log.debug('No width for char %d in font %s.', char, self.texname)
         return 0
 
     def _height_depth_of(self, char):
-        """
-        Height and depth of char in dvi units. For internal use by dviread.py.
-        """
-
+        """Height and depth of char in dvi units."""
         result = []
         for metric, name in ((self._tfm.height, "height"),
                              (self._tfm.depth, "depth")):
             value = metric.get(char, None)
             if value is None:
-                matplotlib.verbose.report(
-                    'No %s for char %d in font %s' % (
-                        name, char, self.texname),
-                    'debug')
+                _log.debug('No %s for char %d in font %s',
+                           name, char, self.texname)
                 result.append(0)
             else:
                 result.append(_mul2012(value, self._scale))
@@ -602,8 +572,8 @@ class DviFont(object):
 
 
 class Vf(Dvi):
-    """
-    A virtual font (\\*.vf file) containing subroutines for dvi files.
+    r"""
+    A virtual font (\*.vf file) containing subroutines for dvi files.
 
     Usage::
 
@@ -613,12 +583,10 @@ class Vf(Dvi):
 
     Parameters
     ----------
-
-    filename : string or bytestring
+    filename : str or path-like
 
     Notes
     -----
-
     The virtual font format is a derivative of dvi:
     http://mirrors.ctan.org/info/knuth/virtual-fonts
     This class reuses some of the machinery of `Dvi`
@@ -642,11 +610,12 @@ class Vf(Dvi):
         Read one page from the file. Return True if successful,
         False if there were no more pages.
         """
-        packet_len, packet_char, packet_width = None, None, None
+        packet_char, packet_ends = None, None
+        packet_len, packet_width = None, None
         while True:
-            byte = ord(self.file.read(1)[0])
+            byte = self.file.read(1)[0]
             # If we are in a packet, execute the dvi instructions
-            if self.state == _dvistate.inpage:
+            if self.state is _dvistate.inpage:
                 byte_at = self.file.tell()-1
                 if byte_at == packet_ends:
                     self._finalize_packet(packet_char, packet_width)
@@ -702,20 +671,18 @@ class Vf(Dvi):
         self.state = _dvistate.outer
 
     def _pre(self, i, x, cs, ds):
-        if self.state != _dvistate.pre:
+        if self.state is not _dvistate.pre:
             raise ValueError("pre command in middle of vf file")
         if i != 202:
             raise ValueError("Unknown vf format %d" % i)
         if len(x):
-            matplotlib.verbose.report('vf file comment: ' + x, 'debug')
+            _log.debug('vf file comment: %s', x)
         self.state = _dvistate.outer
         # cs = checksum, ds = design size
 
 
 def _fix2comp(num):
-    """
-    Convert from two's complement to negative.
-    """
+    """Convert from two's complement to negative."""
     assert 0 <= num < 2**32
     if num & 2**31:
         return num - 2**32
@@ -724,14 +691,12 @@ def _fix2comp(num):
 
 
 def _mul2012(num1, num2):
-    """
-    Multiply two numbers in 20.12 fixed point format.
-    """
+    """Multiply two numbers in 20.12 fixed point format."""
     # Separated into a function because >> has surprising precedence
     return (num1*num2) >> 20
 
 
-class Tfm(object):
+class Tfm:
     """
     A TeX Font Metric file.
 
@@ -739,7 +704,7 @@ class Tfm(object):
 
     Parameters
     ----------
-    filename : string or bytestring
+    filename : str or path-like
 
     Attributes
     ----------
@@ -755,17 +720,16 @@ class Tfm(object):
     __slots__ = ('checksum', 'design_size', 'width', 'height', 'depth')
 
     def __init__(self, filename):
-        matplotlib.verbose.report('opening tfm file ' + filename, 'debug')
+        _log.debug('opening tfm file %s', filename)
         with open(filename, 'rb') as file:
             header1 = file.read(24)
             lh, bc, ec, nw, nh, nd = \
-                struct.unpack(str('!6H'), header1[2:14])
-            matplotlib.verbose.report(
-                'lh=%d, bc=%d, ec=%d, nw=%d, nh=%d, nd=%d' % (
-                    lh, bc, ec, nw, nh, nd), 'debug')
+                struct.unpack('!6H', header1[2:14])
+            _log.debug('lh=%d, bc=%d, ec=%d, nw=%d, nh=%d, nd=%d',
+                       lh, bc, ec, nw, nh, nd)
             header2 = file.read(4*lh)
             self.checksum, self.design_size = \
-                struct.unpack(str('!2I'), header2[:8])
+                struct.unpack('!2I', header2[:8])
             # there is also encoding information etc.
             char_info = file.read(4*(ec-bc+1))
             widths = file.read(4*nw)
@@ -774,11 +738,11 @@ class Tfm(object):
 
         self.width, self.height, self.depth = {}, {}, {}
         widths, heights, depths = \
-            [struct.unpack(str('!%dI') % (len(x)/4), x)
+            [struct.unpack('!%dI' % (len(x)/4), x)
              for x in (widths, heights, depths)]
-        for idx, char in enumerate(xrange(bc, ec+1)):
-            byte0 = ord(char_info[4*idx])
-            byte1 = ord(char_info[4*idx+1])
+        for idx, char in enumerate(range(bc, ec+1)):
+            byte0 = char_info[4*idx]
+            byte1 = char_info[4*idx+1]
             self.width[char] = _fix2comp(widths[byte0])
             self.height[char] = _fix2comp(heights[byte1 >> 4])
             self.depth[char] = _fix2comp(depths[byte1 & 0xf])
@@ -787,7 +751,7 @@ class Tfm(object):
 PsFont = namedtuple('Font', 'texname psname effects encoding filename')
 
 
-class PsfontsMap(object):
+class PsfontsMap:
     """
     A psfonts.map formatted file, mapping TeX fonts to PS fonts.
 
@@ -807,12 +771,10 @@ class PsfontsMap(object):
 
     Parameters
     ----------
-
-    filename : string or bytestring
+    filename : str or path-like
 
     Notes
     -----
-
     For historical reasons, TeX knows many Type-1 fonts by different
     names than the outside world. (For one thing, the names have to
     fit in eight characters.) Also, TeX's native fonts are not Type-1
@@ -835,14 +797,17 @@ class PsfontsMap(object):
     """
     __slots__ = ('_font', '_filename')
 
-    def __init__(self, filename):
+    # Create a filename -> PsfontsMap cache, so that calling
+    # `PsfontsMap(filename)` with the same filename a second time immediately
+    # returns the same object.
+    @lru_cache()
+    def __new__(cls, filename):
+        self = object.__new__(cls)
         self._font = {}
-        self._filename = filename
-        if six.PY3 and isinstance(filename, bytes):
-            encoding = sys.getfilesystemencoding() or 'utf-8'
-            self._filename = filename.decode(encoding, errors='replace')
+        self._filename = os.fsdecode(filename)
         with open(filename, 'rb') as file:
             self._parse(file)
+        return self
 
     def __getitem__(self, texname):
         assert isinstance(texname, bytes)
@@ -859,7 +824,7 @@ class PsfontsMap(object):
             msg = fmt.format(texname.decode('ascii'), self._filename)
             msg = textwrap.fill(msg, break_on_hyphens=False,
                                 break_long_words=False)
-            matplotlib.verbose.report(msg, 'helpful')
+            _log.info(msg)
             raise
         fn, enc = result.filename, result.encoding
         if fn is not None and not fn.startswith(b'/'):
@@ -932,10 +897,8 @@ class PsfontsMap(object):
                        w.group('enc2') or w.group('enc1'))
                 if enc:
                     if encoding is not None:
-                        matplotlib.verbose.report(
-                            'Multiple encodings for %s = %s'
-                            % (texname, psname),
-                            'debug')
+                        _log.debug('Multiple encodings for %s = %s',
+                                   texname, psname)
                     encoding = enc
                     continue
                 # File names are probably unquoted:
@@ -954,9 +917,9 @@ class PsfontsMap(object):
                 encoding=encoding, filename=filename)
 
 
-class Encoding(object):
-    """
-    Parses a \\*.enc file referenced from a psfonts.map style file.
+class Encoding:
+    r"""
+    Parses a \*.enc file referenced from a psfonts.map style file.
     The format this class understands is a very limited subset of
     PostScript.
 
@@ -967,7 +930,7 @@ class Encoding(object):
 
     Parameters
     ----------
-    filename : string or bytestring
+    filename : str or path-like
 
     Attributes
     ----------
@@ -978,19 +941,15 @@ class Encoding(object):
 
     def __init__(self, filename):
         with open(filename, 'rb') as file:
-            matplotlib.verbose.report('Parsing TeX encoding ' + filename,
-                                      'debug-annoying')
+            _log.debug('Parsing TeX encoding %s', filename)
             self.encoding = self._parse(file)
-            matplotlib.verbose.report('Result: ' + repr(self.encoding),
-                                      'debug-annoying')
+            _log.debug('Result: %s', self.encoding)
 
     def __iter__(self):
-        for name in self.encoding:
-            yield name
-
-    def _parse(self, file):
-        result = []
+        yield from self.encoding
 
+    @staticmethod
+    def _parse(file):
         lines = (line.split(b'%', 1)[0].strip() for line in file)
         data = b''.join(lines)
         beginning = data.find(b'[')
@@ -1003,10 +962,42 @@ class Encoding(object):
             raise ValueError("Cannot locate end of encoding in {}"
                              .format(file))
         data = data[:end]
-
         return re.findall(br'/([^][{}<>\s]+)', data)
 
 
+# Note: this function should ultimately replace the Encoding class, which
+# appears to be mostly broken: because it uses b''.join(), there is no
+# whitespace left between glyph names (only slashes) so the final re.findall
+# returns a single string with all glyph names.  However this does not appear
+# to bother backend_pdf, so that needs to be investigated more.  (The fixed
+# version below is necessary for textpath/backend_svg, though.)
+def _parse_enc(path):
+    r"""
+    Parses a \*.enc file referenced from a psfonts.map style file.
+    The format this class understands is a very limited subset of PostScript.
+
+    Parameters
+    ----------
+    path : os.PathLike
+
+    Returns
+    -------
+    encoding : list
+        The nth entry of the list is the PostScript glyph name of the nth
+        glyph.
+    """
+    with open(path, encoding="ascii") as file:
+        no_comments = "\n".join(line.split("%")[0].rstrip() for line in file)
+    array = re.search(r"(?s)\[(.*)\]", no_comments).group(1)
+    lines = [line for line in array.split() if line]
+    if all(line.startswith("/") for line in lines):
+        return [line[1:] for line in lines]
+    else:
+        raise ValueError(
+            "Failed to parse {} as Postscript encoding".format(path))
+
+
+@lru_cache()
 def find_tex_file(filename, format=None):
     """
     Find a file in the texmf tree.
@@ -1016,87 +1007,79 @@ def find_tex_file(filename, format=None):
     kpathsea. It is also available as part of MikTeX, a popular
     distribution on Windows.
 
+    *If the file is not found, an empty string is returned*.
+
     Parameters
     ----------
-    filename : string or bytestring
-    format : string or bytestring
+    filename : str or path-like
+    format : str or bytes
         Used as the value of the `--format` option to :program:`kpsewhich`.
         Could be e.g. 'tfm' or 'vf' to limit the search to that type of files.
 
     References
     ----------
-
     .. [1] `Kpathsea documentation <http://www.tug.org/kpathsea/>`_
         The library that :program:`kpsewhich` is part of.
     """
 
-    cmd = [str('kpsewhich')]
+    # we expect these to always be ascii encoded, but use utf-8
+    # out of caution
+    if isinstance(filename, bytes):
+        filename = filename.decode('utf-8', errors='replace')
+    if isinstance(format, bytes):
+        format = format.decode('utf-8', errors='replace')
+
+    if os.name == 'nt':
+        # On Windows only, kpathsea can use utf-8 for cmd args and output.
+        # The `command_line_encoding` environment variable is set to force it
+        # to always use utf-8 encoding.  See Matplotlib issue #11848.
+        kwargs = dict(env=dict(os.environ, command_line_encoding='utf-8'))
+    else:
+        kwargs = {}
+
+    cmd = ['kpsewhich']
     if format is not None:
         cmd += ['--format=' + format]
     cmd += [filename]
-
-    matplotlib.verbose.report('find_tex_file(%s): %s'
-                              % (filename, cmd), 'debug')
-    # stderr is unused, but reading it avoids a subprocess optimization
-    # that breaks EINTR handling in some Python versions:
-    # http://bugs.python.org/issue12493
-    # https://github.com/matplotlib/matplotlib/issues/633
-    pipe = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE)
-    result = pipe.communicate()[0].rstrip()
-    matplotlib.verbose.report('find_tex_file result: %s' % result,
-                              'debug')
-    return result.decode('ascii')
-
-# With multiple text objects per figure (e.g., tick labels) we may end
-# up reading the same tfm and vf files many times, so we implement a
-# simple cache. TODO: is this worth making persistent?
-
-_tfmcache = {}
-_vfcache = {}
-
-
-def _fontfile(texname, class_, suffix, cache):
     try:
-        return cache[texname]
-    except KeyError:
-        pass
-
-    filename = find_tex_file(texname + suffix)
-    if filename:
-        result = class_(filename)
+        result = cbook._check_and_log_subprocess(cmd, _log, **kwargs)
+    except RuntimeError:
+        return ''
+    if os.name == 'nt':
+        return result.decode('utf-8').rstrip('\r\n')
     else:
-        result = None
-
-    cache[texname] = result
-    return result
+        return os.fsdecode(result).rstrip('\n')
 
 
-def _tfmfile(texname):
-    return _fontfile(texname, Tfm, '.tfm', _tfmcache)
+@lru_cache()
+def _fontfile(cls, suffix, texname):
+    filename = find_tex_file(texname + suffix)
+    return cls(filename) if filename else None
 
 
-def _vffile(texname):
-    return _fontfile(texname, Vf, '.vf', _vfcache)
+_tfmfile = partial(_fontfile, Tfm, ".tfm")
+_vffile = partial(_fontfile, Vf, ".vf")
 
 
 if __name__ == '__main__':
-    import sys
-    matplotlib.verbose.set_level('debug-annoying')
-    fname = sys.argv[1]
-    try:
-        dpi = float(sys.argv[2])
-    except IndexError:
-        dpi = None
-    with Dvi(fname, dpi) as dvi:
+    from argparse import ArgumentParser
+    import itertools
+
+    parser = ArgumentParser()
+    parser.add_argument("filename")
+    parser.add_argument("dpi", nargs="?", type=float, default=None)
+    args = parser.parse_args()
+    with Dvi(args.filename, args.dpi) as dvi:
         fontmap = PsfontsMap(find_tex_file('pdftex.map'))
         for page in dvi:
             print('=== new page ===')
-            fPrev = None
-            for x, y, f, c, w in page.text:
-                if f != fPrev:
-                    print('font', f.texname, 'scaled', f._scale/pow(2.0, 20))
-                    fPrev = f
-                print(x, y, c, 32 <= c < 128 and chr(c) or '.', w)
+            for font, group in itertools.groupby(
+                    page.text, lambda text: text.font):
+                print('font', font.texname, 'scaled', font._scale / 2 ** 20)
+                for text in group:
+                    print(text.x, text.y, text.glyph,
+                          chr(text.glyph) if chr(text.glyph).isprintable()
+                          else ".",
+                          text.width)
             for x, y, w, h in page.boxes:
                 print(x, y, 'BOX', w, h)
